@@ -1,7 +1,6 @@
 from pydantic import BaseModel
 
 from foundry.core.drawable.Drawable import Drawable
-from foundry.core.drawable.DrawableGenerator import DrawableGeneratator
 from foundry.core.warnings.Warning import Warning
 from foundry.core.warnings.WarningCreator import WarningCreator
 
@@ -9,7 +8,7 @@ from foundry.core.warnings.WarningCreator import WarningCreator
 class Definition(BaseModel):
     description: str = ""
     warnings: list[WarningCreator] = []
-    overlays: list[DrawableGeneratator] = []
+    overlays: list[Drawable] = []
 
     def get_warnings(self) -> list[Warning]:
         return self.warnings.copy()  # type: ignore
