@@ -3,9 +3,9 @@ from functools import lru_cache
 from PySide6.QtCore import QPoint
 from PySide6.QtGui import QColor, QImage, QPainter, Qt
 
-from foundry.core.graphics_set.GraphicsSet import GraphicsSetProtocol
+from foundry.core.graphics_set.GraphicsSet import GraphicsSet
 from foundry.core.palette import NESPalette
-from foundry.core.palette.PaletteGroup import MutablePaletteGroupProtocol
+from foundry.core.palette.PaletteGroup import PaletteGroup
 from foundry.game.File import ROM
 from foundry.game.gfx.drawable import MASK_COLOR, apply_selection_overlay
 from foundry.game.gfx.drawable.Tile import Tile
@@ -14,9 +14,9 @@ from foundry.game.gfx.drawable.Tile import Tile
 @lru_cache(2**10)
 def get_sprite(
     index: int,
-    palette_group: MutablePaletteGroupProtocol,
+    palette_group: PaletteGroup,
     palette_index: int,
-    graphics_set: GraphicsSetProtocol,
+    graphics_set: GraphicsSet,
     horizontal_mirror: bool = False,
     vertical_mirror: bool = False,
 ):
@@ -38,9 +38,9 @@ class Sprite:
     def __init__(
         self,
         index: int,
-        palette_group: MutablePaletteGroupProtocol,
+        palette_group: PaletteGroup,
         palette_index: int,
-        graphics_set: GraphicsSetProtocol,
+        graphics_set: GraphicsSet,
         horizontal_mirror: bool = False,
         vertical_mirror: bool = False,
     ):
