@@ -2,9 +2,9 @@ from functools import lru_cache
 
 from PySide6.QtGui import QImage
 
-from foundry.core.graphics_set.GraphicsSet import GraphicsSetProtocol
+from foundry.core.graphics_set.GraphicsSet import GraphicsSet
 from foundry.core.palette import NESPalette
-from foundry.core.palette.PaletteGroup import MutablePaletteGroup
+from foundry.core.palette.PaletteGroup import PaletteGroup
 from foundry.game.gfx.drawable import MASK_COLOR, bit_reverse
 
 PIXEL_OFFSET = 8  # both bits describing the color of a pixel are in separate 8 byte chunks at the same index
@@ -24,9 +24,9 @@ class Tile:
     def __init__(
         self,
         object_index: int,
-        palette_group: MutablePaletteGroup,
+        palette_group: PaletteGroup,
         palette_index: int,
-        graphics_set: GraphicsSetProtocol,
+        graphics_set: GraphicsSet,
         mirrored=False,
     ):
         start = object_index * Tile.SIZE
