@@ -1,7 +1,7 @@
 from PySide6.QtCore import QPoint, QSize
 
 from foundry.core.graphics_set.GraphicsSet import GraphicsSet
-from foundry.core.palette.PaletteGroup import MutablePaletteGroup
+from foundry.core.palette.PaletteGroup import PaletteGroup
 from foundry.game.File import ROM
 from foundry.game.gfx.drawable.Block import Block
 from foundry.game.gfx.objects.MapObject import MapObject
@@ -26,7 +26,7 @@ class WorldMap(LevelLike):
         self.name = f"World {world_index} - Overworld"
 
         self.graphics_set = GraphicsSet.from_tileset(OVERWORLD_GRAPHIC_SET)
-        self.palette_group = MutablePaletteGroup.from_tileset(WORLD_MAP_OBJECT_SET, 0)
+        self.palette_group = PaletteGroup.from_tileset(WORLD_MAP_OBJECT_SET, 0)
 
         self.object_set = WORLD_MAP_OBJECT_SET
         self.tsa_data = ROM.get_tsa_data(self.object_set)
