@@ -13,7 +13,7 @@ from PySide6.QtWidgets import QLayout, QStatusBar, QToolBar, QWidget
 from foundry import icon
 from foundry.core.geometry import Point
 from foundry.core.graphics_set.GraphicsSet import GraphicsSet
-from foundry.core.palette.PaletteGroup import MutablePaletteGroup
+from foundry.core.palette.PaletteGroup import PaletteGroup
 from foundry.game.gfx.drawable.Block import Block
 from foundry.gui.CustomChildWindow import CustomChildWindow
 from foundry.gui.PatternViewer import PatternViewerController as PatternViewer
@@ -24,7 +24,7 @@ class BlockEditorModel:
     tile_square_assembly: bytearray
     block_index: int
     graphics_set: GraphicsSet
-    palette_group: MutablePaletteGroup
+    palette_group: PaletteGroup
     palette_index: int
 
 
@@ -32,7 +32,7 @@ class BlockEditorController(CustomChildWindow):
     tile_square_assembly_changed: SignalInstance = Signal(bytearray)  # type: ignore
     block_index_changed: SignalInstance = Signal(int)  # type: ignore
     graphics_set_changed: SignalInstance = Signal(GraphicsSet)  # type: ignore
-    palette_group_changed: SignalInstance = Signal(MutablePaletteGroup)  # type: ignore
+    palette_group_changed: SignalInstance = Signal(PaletteGroup)  # type: ignore
     palette_index_changed: SignalInstance = Signal(int)  # type: ignore
     destroyed: SignalInstance = Signal()  # type: ignore
 
@@ -42,7 +42,7 @@ class BlockEditorController(CustomChildWindow):
         tsa_data: bytearray,
         block_index: int,
         graphics_set: GraphicsSet,
-        palette_group: MutablePaletteGroup,
+        palette_group: PaletteGroup,
         palette_index: int,
     ):
         super().__init__(parent, "Block Editor")
@@ -120,11 +120,11 @@ class BlockEditorController(CustomChildWindow):
             self.pattern_viewer.graphics_set = value
 
     @property
-    def palette_group(self) -> MutablePaletteGroup:
+    def palette_group(self) -> PaletteGroup:
         return self.model.palette_group
 
     @palette_group.setter
-    def palette_group(self, value: MutablePaletteGroup):
+    def palette_group(self, value: PaletteGroup):
         self.model.palette_group = value
         self.view.palette_group = value
         self.palette_group_changed.emit(self.palette_group)
@@ -178,7 +178,7 @@ class BlockEditorView(QWidget):
         tsa_data: bytearray,
         block_index: int,
         graphics_set: GraphicsSet,
-        palette_group: MutablePaletteGroup,
+        palette_group: PaletteGroup,
         palette_index: int,
         zoom: int = 16,
     ):
