@@ -4,7 +4,7 @@ from foundry.core.palette import (
     PALETTE_GROUPS_PER_OBJECT_SET,
     PALETTES_PER_PALETTES_GROUP,
 )
-from foundry.core.palette.PaletteGroup import MutablePaletteGroup
+from foundry.core.palette.PaletteGroup import PaletteGroup
 from foundry.game.level.LevelRef import LevelRef
 from foundry.gui.CustomDialog import CustomDialog
 from foundry.gui.PaletteWidget import PaletteWidget
@@ -14,7 +14,7 @@ class PaletteViewer(CustomDialog):
     palettes_per_row = 4
 
     def __init__(self, parent, level_ref: LevelRef):
-        title = f"MutablePalette Groups for Object Set {level_ref.level.object_set_number}"
+        title = f"Palette Groups for Object Set {level_ref.level.object_set_number}"
 
         super().__init__(parent, title=title)
 
@@ -24,12 +24,12 @@ class PaletteViewer(CustomDialog):
 
         for palette_group in range(PALETTE_GROUPS_PER_OBJECT_SET):
             group_box = QGroupBox()
-            group_box.setTitle(f"MutablePalette Group {palette_group}")
+            group_box.setTitle(f"Palette Group {palette_group}")
 
             group_box_layout = QVBoxLayout(group_box)
             group_box_layout.setSpacing(0)
 
-            pal = MutablePaletteGroup.from_tileset(self.level_ref.level.object_set_number, palette_group)
+            pal = PaletteGroup.from_tileset(self.level_ref.level.object_set_number, palette_group)
 
             for idx in range(PALETTES_PER_PALETTES_GROUP):
                 group_box_layout.addWidget(PaletteWidget(self, pal[idx]))
